/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtStateMachine.h"

#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtStateMachine/qkeyeventtransition.sip"
#include <qkeyeventtransition.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtStateMachine/sipQtStateMachineQKeyEventTransition.cpp"

#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtStateMachine/qstate.sip"
#include <qstate.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtStateMachine/sipQtStateMachineQKeyEventTransition.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 36 "/build/pyqt6/src/pyqt6-6.11.0/build/QtStateMachine/sipQtStateMachineQKeyEventTransition.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 39 "/build/pyqt6/src/pyqt6-6.11.0/build/QtStateMachine/sipQtStateMachineQKeyEventTransition.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 42 "/build/pyqt6/src/pyqt6-6.11.0/build/QtStateMachine/sipQtStateMachineQKeyEventTransition.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qtextstream.sip"
#include <qtextstream.h>
#line 47 "/build/pyqt6/src/pyqt6-6.11.0/build/QtStateMachine/sipQtStateMachineQKeyEventTransition.cpp"
#line 135 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 50 "/build/pyqt6/src/pyqt6-6.11.0/build/QtStateMachine/sipQtStateMachineQKeyEventTransition.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qabstractanimation.sip"
#include <qabstractanimation.h>
#line 53 "/build/pyqt6/src/pyqt6-6.11.0/build/QtStateMachine/sipQtStateMachineQKeyEventTransition.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtStateMachine/qstatemachine.sip"
#include <qstatemachine.h>
#line 56 "/build/pyqt6/src/pyqt6-6.11.0/build/QtStateMachine/sipQtStateMachineQKeyEventTransition.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtStateMachine/qabstracttransition.sip"
#include <qabstracttransition.h>
#line 59 "/build/pyqt6/src/pyqt6-6.11.0/build/QtStateMachine/sipQtStateMachineQKeyEventTransition.cpp"
#line 135 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 62 "/build/pyqt6/src/pyqt6-6.11.0/build/QtStateMachine/sipQtStateMachineQKeyEventTransition.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtStateMachine/qabstractstate.sip"
#include <qabstractstate.h>
#line 65 "/build/pyqt6/src/pyqt6-6.11.0/build/QtStateMachine/sipQtStateMachineQKeyEventTransition.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 70 "/build/pyqt6/src/pyqt6-6.11.0/build/QtStateMachine/sipQtStateMachineQKeyEventTransition.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 73 "/build/pyqt6/src/pyqt6-6.11.0/build/QtStateMachine/sipQtStateMachineQKeyEventTransition.cpp"
#line 277 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 76 "/build/pyqt6/src/pyqt6-6.11.0/build/QtStateMachine/sipQtStateMachineQKeyEventTransition.cpp"
#line 254 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 79 "/build/pyqt6/src/pyqt6-6.11.0/build/QtStateMachine/sipQtStateMachineQKeyEventTransition.cpp"
#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 82 "/build/pyqt6/src/pyqt6-6.11.0/build/QtStateMachine/sipQtStateMachineQKeyEventTransition.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 85 "/build/pyqt6/src/pyqt6-6.11.0/build/QtStateMachine/sipQtStateMachineQKeyEventTransition.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 88 "/build/pyqt6/src/pyqt6-6.11.0/build/QtStateMachine/sipQtStateMachineQKeyEventTransition.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 91 "/build/pyqt6/src/pyqt6-6.11.0/build/QtStateMachine/sipQtStateMachineQKeyEventTransition.cpp"
#line 135 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 94 "/build/pyqt6/src/pyqt6-6.11.0/build/QtStateMachine/sipQtStateMachineQKeyEventTransition.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 97 "/build/pyqt6/src/pyqt6-6.11.0/build/QtStateMachine/sipQtStateMachineQKeyEventTransition.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qanystringview.sip"
#include <qanystringview.h>
#line 100 "/build/pyqt6/src/pyqt6-6.11.0/build/QtStateMachine/sipQtStateMachineQKeyEventTransition.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 103 "/build/pyqt6/src/pyqt6-6.11.0/build/QtStateMachine/sipQtStateMachineQKeyEventTransition.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 106 "/build/pyqt6/src/pyqt6-6.11.0/build/QtStateMachine/sipQtStateMachineQKeyEventTransition.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 109 "/build/pyqt6/src/pyqt6-6.11.0/build/QtStateMachine/sipQtStateMachineQKeyEventTransition.cpp"


class sipQKeyEventTransition : public ::QKeyEventTransition
{
public:
    sipQKeyEventTransition(::QState*);
    sipQKeyEventTransition(::QObject*, ::QEvent::Type, int, ::QState*);
    virtual ~sipQKeyEventTransition();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    void onTransition(::QEvent*) SIP_OVERRIDE;
    bool eventTest(::QEvent*) SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQKeyEventTransition(const sipQKeyEventTransition &);
    sipQKeyEventTransition &operator = (const sipQKeyEventTransition &);

    char sipPyMethods[9];
};

sipQKeyEventTransition::sipQKeyEventTransition(::QState*a0): ::QKeyEventTransition(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQKeyEventTransition::sipQKeyEventTransition(::QObject*a0, ::QEvent::Type a1, int a2, ::QState*a3): ::QKeyEventTransition(a0, a1, a2, a3), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQKeyEventTransition::~sipQKeyEventTransition()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQKeyEventTransition::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtStateMachine_qt_metaobject(sipPySelf, sipType_QKeyEventTransition);

    return ::QKeyEventTransition::metaObject();
}

int sipQKeyEventTransition::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QKeyEventTransition::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtStateMachine_qt_metacall(sipPySelf, sipType_QKeyEventTransition, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQKeyEventTransition::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtStateMachine_qt_metacast(sipPySelf, sipType_QKeyEventTransition, _clname, &sipCpp) ? sipCpp : ::QKeyEventTransition::qt_metacast(_clname));
}

void sipQKeyEventTransition::onTransition(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_onTransition);

    if (!sipMeth)
    {
        ::QKeyEventTransition::onTransition(a0);
        return;
    }

    extern void sipVH_QtStateMachine_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtStateMachine_1(sipGILState, sipImportedVirtErrorHandlers_QtStateMachine_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQKeyEventTransition::eventTest(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_eventTest);

    if (!sipMeth)
        return ::QKeyEventTransition::eventTest(a0);

    extern bool sipVH_QtStateMachine_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtStateMachine_5(sipGILState, sipImportedVirtErrorHandlers_QtStateMachine_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQKeyEventTransition::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QKeyEventTransition::event(a0);

    extern bool sipVH_QtStateMachine_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtStateMachine_5(sipGILState, sipImportedVirtErrorHandlers_QtStateMachine_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQKeyEventTransition::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QKeyEventTransition::eventFilter(a0, a1);

    extern bool sipVH_QtStateMachine_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtStateMachine_4(sipGILState, sipImportedVirtErrorHandlers_QtStateMachine_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQKeyEventTransition::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QKeyEventTransition::timerEvent(a0);
        return;
    }

    extern void sipVH_QtStateMachine_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtStateMachine_3(sipGILState, sipImportedVirtErrorHandlers_QtStateMachine_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQKeyEventTransition::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QKeyEventTransition::childEvent(a0);
        return;
    }

    extern void sipVH_QtStateMachine_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtStateMachine_2(sipGILState, sipImportedVirtErrorHandlers_QtStateMachine_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQKeyEventTransition::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QKeyEventTransition::customEvent(a0);
        return;
    }

    extern void sipVH_QtStateMachine_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtStateMachine_1(sipGILState, sipImportedVirtErrorHandlers_QtStateMachine_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQKeyEventTransition::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[7], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QKeyEventTransition::connectNotify(a0);
        return;
    }

    extern void sipVH_QtStateMachine_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtStateMachine_0(sipGILState, sipImportedVirtErrorHandlers_QtStateMachine_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQKeyEventTransition::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[8], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QKeyEventTransition::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtStateMachine_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtStateMachine_0(sipGILState, sipImportedVirtErrorHandlers_QtStateMachine_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QKeyEventTransition_key, "key(self) -> int");

extern "C" {static PyObject *meth_QKeyEventTransition_key(PyObject *, PyObject *);}
static PyObject *meth_QKeyEventTransition_key(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QKeyEventTransition *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QKeyEventTransition, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->key();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QKeyEventTransition, sipName_key, doc_QKeyEventTransition_key);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QKeyEventTransition_setKey, "setKey(self, key: int)");

extern "C" {static PyObject *meth_QKeyEventTransition_setKey(PyObject *, PyObject *);}
static PyObject *meth_QKeyEventTransition_setKey(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QKeyEventTransition *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QKeyEventTransition, &sipCpp, &a0))
        {
            sipCpp->setKey(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QKeyEventTransition, sipName_setKey, doc_QKeyEventTransition_setKey);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QKeyEventTransition_modifierMask, "modifierMask(self) -> Qt.KeyboardModifier");

extern "C" {static PyObject *meth_QKeyEventTransition_modifierMask(PyObject *, PyObject *);}
static PyObject *meth_QKeyEventTransition_modifierMask(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QKeyEventTransition *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QKeyEventTransition, &sipCpp))
        {
            ::Qt::KeyboardModifiers*sipRes;

            sipRes = new ::Qt::KeyboardModifiers(sipCpp->modifierMask());

            return sipConvertFromNewType(sipRes, sipType_QFlags_0100Qt_KeyboardModifier, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QKeyEventTransition, sipName_modifierMask, doc_QKeyEventTransition_modifierMask);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QKeyEventTransition_setModifierMask, "setModifierMask(self, modifiers: Qt.KeyboardModifier)");

extern "C" {static PyObject *meth_QKeyEventTransition_setModifierMask(PyObject *, PyObject *);}
static PyObject *meth_QKeyEventTransition_setModifierMask(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt::KeyboardModifiers* a0;
        int a0State = 0;
        ::QKeyEventTransition *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QKeyEventTransition, &sipCpp, sipType_QFlags_0100Qt_KeyboardModifier, &a0, &a0State))
        {
            sipCpp->setModifierMask(*a0);
            sipReleaseType(a0, sipType_QFlags_0100Qt_KeyboardModifier, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QKeyEventTransition, sipName_setModifierMask, doc_QKeyEventTransition_setModifierMask);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QKeyEventTransition_onTransition, "onTransition(self, event: QEvent|None)");

extern "C" {static PyObject *meth_QKeyEventTransition_onTransition(PyObject *, PyObject *);}
static PyObject *meth_QKeyEventTransition_onTransition(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QKeyEventTransition)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QEvent* a0;
        ::QKeyEventTransition *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QKeyEventTransition, &sipCpp, sipType_QEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QKeyEventTransition::onTransition(a0) : sipCpp->onTransition(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QKeyEventTransition, sipName_onTransition, doc_QKeyEventTransition_onTransition);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QKeyEventTransition_eventTest, "eventTest(self, event: QEvent|None) -> bool");

extern "C" {static PyObject *meth_QKeyEventTransition_eventTest(PyObject *, PyObject *);}
static PyObject *meth_QKeyEventTransition_eventTest(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QKeyEventTransition)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QEvent* a0;
        ::QKeyEventTransition *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QKeyEventTransition, &sipCpp, sipType_QEvent, &a0))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QKeyEventTransition::eventTest(a0) : sipCpp->eventTest(a0));

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QKeyEventTransition, sipName_eventTest, doc_QKeyEventTransition_eventTest);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QKeyEventTransition(void *, const sipTypeDef *);}
static void *cast_QKeyEventTransition(void *sipCppV, const sipTypeDef *targetType)
{
    ::QKeyEventTransition *sipCpp = reinterpret_cast< ::QKeyEventTransition *>(sipCppV);

    if (targetType == sipType_QKeyEventTransition)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_QEventTransition)->ctd_cast(static_cast< ::QEventTransition *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QKeyEventTransition(void *, int);}
static void release_QKeyEventTransition(void *sipCppV, int)
{
    ::QKeyEventTransition *sipCpp = reinterpret_cast< ::QKeyEventTransition *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_QKeyEventTransition(Py_ssize_t);}
static void *array_QKeyEventTransition(Py_ssize_t sipNrElem)
{
    return new ::QKeyEventTransition[sipNrElem];
}


extern "C" {static void array_delete_QKeyEventTransition(void *);}
static void array_delete_QKeyEventTransition(void *sipCpp)
{
    delete[] reinterpret_cast< ::QKeyEventTransition *>(sipCpp);
}


extern "C" {static void dealloc_QKeyEventTransition(sipSimpleWrapper *);}
static void dealloc_QKeyEventTransition(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQKeyEventTransition *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QKeyEventTransition(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QKeyEventTransition(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QKeyEventTransition(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQKeyEventTransition *sipCpp = SIP_NULLPTR;

    {
        ::QState* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_sourceState,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_QState, &a0, sipOwner))
        {
            sipCpp = new sipQKeyEventTransition(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    {
        ::QObject* a0;
        PyObject *a0Keep;
        ::QEvent::Type a1;
        int a2;
        ::QState* a3 = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_sourceState,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "@J8Ei|JH", &a0Keep, sipType_QObject, &a0, sipType_QEvent_Type, &a1, &a2, sipType_QState, &a3, sipOwner))
        {
            sipCpp = new sipQKeyEventTransition(a0, a1, a2, a3);

            sipKeepReference((PyObject *)sipSelf, 10, a0Keep);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QKeyEventTransition[] = {{3, 255, 1}};


static PyMethodDef methods_QKeyEventTransition[] = {
    {sipName_eventTest, meth_QKeyEventTransition_eventTest, METH_VARARGS, doc_QKeyEventTransition_eventTest},
    {sipName_key, meth_QKeyEventTransition_key, METH_VARARGS, doc_QKeyEventTransition_key},
    {sipName_modifierMask, meth_QKeyEventTransition_modifierMask, METH_VARARGS, doc_QKeyEventTransition_modifierMask},
    {sipName_onTransition, meth_QKeyEventTransition_onTransition, METH_VARARGS, doc_QKeyEventTransition_onTransition},
    {sipName_setKey, meth_QKeyEventTransition_setKey, METH_VARARGS, doc_QKeyEventTransition_setKey},
    {sipName_setModifierMask, meth_QKeyEventTransition_setModifierMask, METH_VARARGS, doc_QKeyEventTransition_setModifierMask}
};

PyDoc_STRVAR(doc_QKeyEventTransition, "\1QKeyEventTransition(sourceState: QState|None = None)\n"
"QKeyEventTransition(object: QObject|None, type: QEvent.Type, key: int, sourceState: QState|None = None)");


static pyqt6ClassPluginDef plugin_QKeyEventTransition = {
    &::QKeyEventTransition::staticMetaObject,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtStateMachine_QKeyEventTransition = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QKeyEventTransition,
        SIP_NULLPTR,
        &plugin_QKeyEventTransition,
    },
    {
        sipNameNr_QKeyEventTransition,
        {0, 0, 1},
        6, methods_QKeyEventTransition,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QKeyEventTransition,
    -1,
    -1,
    supers_QKeyEventTransition,
    SIP_NULLPTR,
    init_type_QKeyEventTransition,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QKeyEventTransition,
    SIP_NULLPTR,
    array_QKeyEventTransition,
    SIP_NULLPTR,
    release_QKeyEventTransition,
    cast_QKeyEventTransition,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QKeyEventTransition,
    sizeof (::QKeyEventTransition),
};
